# DLL (Deep Learning Library)

DLL is a deep learning library inspired by TensorFlow and PyTorch. This is my largest project to date, featuring thousands of lines of code. It encompasses a wide range of deep learning and machine learning methods, and includes numerous examples and tests to demonstrate their usage. Feel free to explore the source code and experiment with the models using the documentation.

## Documentation:

Checkout the documentation of DLL [here](https://naapeli.github.io/deep-learning-library/).

## Installation

One can get an installation of this library by the following command:

```
pip install PyDLLib
```

After installation, one can use the library as described in the [documentation](https://naapeli.github.io/deep-learning-library/api/DLL.html) and in the [examples](https://naapeli.github.io/deep-learning-library/auto_examples/index.html).


## Running Tests

To run the tests, one can clone the GitHub [repository](https://github.com/naapeli/deep-learning-library) to a local folder, navigate to the deep-learning-library-folder and use eg. the following command:

```
python -m Tests.ReinforcementLearning.DeepReinforcementLearning
```

Feel free to explore the code and apply it to new problems!
